summaryrefslogtreecommitdiff
path: root/libs/ardour/sndfileimportable.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2017-09-18 12:39:17 -0400
committerPaul Davis <paul@linuxaudiosystems.com>2017-09-18 12:39:17 -0400
commit30b087ab3d28f1585987fa3f6ae006562ae192e3 (patch)
tree620ae0250b5d77f90a18f8c2b83be61e4fe7b0b5 /libs/ardour/sndfileimportable.cc
parentcb956e3e480716a3efd280a5287bdd7bee1cedc5 (diff)
globally change all use of "frame" to refer to audio into "sample".
Generated by tools/f2s. Some hand-editing will be required in a few places to fix up comments related to timecode and video in order to keep the legible
Diffstat (limited to 'libs/ardour/sndfileimportable.cc')
-rw-r--r--libs/ardour/sndfileimportable.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/libs/ardour/sndfileimportable.cc b/libs/ardour/sndfileimportable.cc
index 95b269a014..f900689f77 100644
--- a/libs/ardour/sndfileimportable.cc
+++ b/libs/ardour/sndfileimportable.cc
@@ -47,7 +47,7 @@ SndFileImportableSource::get_timecode_info (SNDFILE* sf, SF_BROADCAST_INFO* binf
* 0xffffffff 0xfffc5680
* seems to be a bug in Presonus Capture (which generated the file)
*
* still since framepos_t is a signed int, ignore files that could
* lead to negative timestamps for now.
*/
@@ -97,10 +97,10 @@ SndFileImportableSource::~SndFileImportableSource ()
{
}
-framecnt_t
-SndFileImportableSource::read (Sample* buffer, framecnt_t nframes)
+samplecnt_t
+SndFileImportableSource::read (Sample* buffer, samplecnt_t nframes)
{
- framecnt_t per_channel = nframes / sf_info.channels;
+ samplecnt_t per_channel = nframes / sf_info.channels;
per_channel = sf_readf_float (in.get(), buffer, per_channel);
return per_channel * sf_info.channels;
}
@@ -111,28 +111,28 @@ SndFileImportableSource::channels () const
return sf_info.channels;
}
-framecnt_t
+samplecnt_t
SndFileImportableSource::length () const
{
- return (framecnt_t) sf_info.frames;
+ return (samplecnt_t) sf_info.frames;
}
-framecnt_t
+samplecnt_t
SndFileImportableSource::samplerate () const
{
return sf_info.samplerate;
}
void
-SndFileImportableSource::seek (framepos_t /*pos*/)
+SndFileImportableSource::seek (samplepos_t /*pos*/)
{
sf_seek (in.get(), 0, SEEK_SET);
}
-framepos_t
+samplepos_t
SndFileImportableSource::natural_position () const
{
- return (framepos_t) timecode;
+ return (samplepos_t) timecode;
}
bool
@@ -47,7 +47,7 @@ SndFileImportableSource::get_timecode_info (SNDFILE* sf, SF_BROADCAST_INFO* binf
* seems to be a bug in Presonus Capture (which generated the file)
*
- * still since framepos_t is a signed int, ignore files that could
+ * still since samplepos_t is a signed int, ignore files that could
* lead to negative timestamps for now.
*/